@@ -1,18 +1,15 @@
-use std::process::Command;
-
 use anyhow::Result;
 use assert_cmd::prelude::*;
 use assert_fs::fixture::ChildPath;
 use assert_fs::prelude::*;
 
-use crate::common::{TestContext, get_bin, uv_snapshot};
+use crate::common::{TestContext, uv_snapshot};
 
 #[test]
 fn no_arguments() {
-    uv_snapshot!(Command::new(get_bin())
-        .arg("pip")
-        .arg("uninstall")
-        .env_clear(), @r###"
+    let context = TestContext::new("3.12");
+
+    uv_snapshot!(context.filters(), context.pip_uninstall(), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -21,22 +18,19 @@ fn no_arguments() {
     error: the following required arguments were not provided:
       <PACKAGE|--requirements <REQUIREMENTS>>
 
-    Usage: uv pip uninstall <PACKAGE|--requirements <REQUIREMENTS>>
+    Usage: uv pip uninstall --cache-dir [CACHE_DIR] <PACKAGE|--requirements <REQUIREMENTS>>
 
     For more information, try '--help'.
-    "###
+    "
     );
 }
 
 #[test]
-fn invalid_requirement() -> Result<()> {
-    let temp_dir = assert_fs::TempDir::new()?;
+fn invalid_requirement() {
+    let context = TestContext::new("3.12");
 
-    uv_snapshot!(Command::new(get_bin())
-        .arg("pip")
-        .arg("uninstall")
-        .arg("flask==1.0.x")
-        .current_dir(&temp_dir), @r###"
+    uv_snapshot!(context.filters(), context.pip_uninstall()
+        .arg("flask==1.0.x"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -46,45 +40,36 @@ fn invalid_requirement() -> Result<()> {
       Caused by: after parsing `1.0`, found `.x`, which is not part of a valid version
     flask==1.0.x
          ^^^^^^^
-    "###);
-
-    Ok(())
+    ");
 }
 
 #[test]
-fn missing_requirements_txt() -> Result<()> {
-    let temp_dir = assert_fs::TempDir::new()?;
+fn missing_requirements_txt() {
+    let context = TestContext::new("3.12");
 
-    uv_snapshot!(Command::new(get_bin())
-        .arg("pip")
-        .arg("uninstall")
+    uv_snapshot!(context.filters(), context.pip_uninstall()
         .arg("-r")
-        .arg("requirements.txt")
-        .current_dir(&temp_dir), @r###"
+        .arg("requirements.txt"), @"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
     error: File not found: `requirements.txt`
-    "###
+    "
     );
-
-    Ok(())
 }
 
 #[test]
 fn invalid_requirements_txt_requirement() -> Result<()> {
-    let temp_dir = assert_fs::TempDir::new()?;
-    let requirements_txt = temp_dir.child("requirements.txt");
+    let context = TestContext::new("3.12");
+
+    let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("flask==1.0.x")?;
 
-    uv_snapshot!(Command::new(get_bin())
-        .arg("pip")
-        .arg("uninstall")
+    uv_snapshot!(context.filters(), context.pip_uninstall()
         .arg("-r")
-        .arg("requirements.txt")
-        .current_dir(&temp_dir), @r###"
+        .arg("requirements.txt"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -94,7 +79,7 @@ fn invalid_requirements_txt_requirement() -> Result<()> {
       Caused by: after parsing `1.0`, found `.x`, which is not part of a valid version
     flask==1.0.x
          ^^^^^^^
-    "###);
+    ");
 
     Ok(())
 }
@@ -116,7 +101,7 @@ fn uninstall() -> Result<()> {
     context.assert_command("import markupsafe").success();
 
     uv_snapshot!(context.pip_uninstall()
-        .arg("MarkupSafe"), @r###"
+        .arg("MarkupSafe"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -124,7 +109,7 @@ fn uninstall() -> Result<()> {
     ----- stderr -----
     Uninstalled 1 package in [TIME]
      - markupsafe==2.1.3
-    "###
+    "
     );
 
     context.assert_command("import markupsafe").failure();
@@ -153,7 +138,7 @@ fn missing_record() -> Result<()> {
     fs_err::remove_file(dist_info.join("RECORD"))?;
 
     uv_snapshot!(context.filters(), context.pip_uninstall()
-        .arg("MarkupSafe"), @r"
+        .arg("MarkupSafe"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -191,7 +176,7 @@ fn uninstall_editable_by_name() -> Result<()> {
 
     // Uninstall the editable by name.
     uv_snapshot!(context.filters(), context.pip_uninstall()
-        .arg("flit-editable"), @r###"
+        .arg("flit-editable"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -199,7 +184,7 @@ fn uninstall_editable_by_name() -> Result<()> {
     ----- stderr -----
     Uninstalled 1 package in [TIME]
      - flit-editable==0.1.0 (from file://[WORKSPACE]/test/packages/flit_editable)
-    "###
+    "
     );
 
     context.assert_command("import flit_editable").failure();
@@ -232,7 +217,7 @@ fn uninstall_by_path() -> Result<()> {
 
     // Uninstall the editable by path.
     uv_snapshot!(context.filters(), context.pip_uninstall()
-        .arg(context.workspace_root.join("test/packages/flit_editable")), @r###"
+        .arg(context.workspace_root.join("test/packages/flit_editable")), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -240,7 +225,7 @@ fn uninstall_by_path() -> Result<()> {
     ----- stderr -----
     Uninstalled 1 package in [TIME]
      - flit-editable==0.1.0 (from file://[WORKSPACE]/test/packages/flit_editable)
-    "###
+    "
     );
 
     context.assert_command("import flit_editable").failure();
@@ -274,7 +259,7 @@ fn uninstall_duplicate_by_path() -> Result<()> {
     // Uninstall the editable by both path and name.
     uv_snapshot!(context.filters(), context.pip_uninstall()
         .arg("flit-editable")
-        .arg(context.workspace_root.join("test/packages/flit_editable")), @r###"
+        .arg(context.workspace_root.join("test/packages/flit_editable")), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -282,7 +267,7 @@ fn uninstall_duplicate_by_path() -> Result<()> {
     ----- stderr -----
     Uninstalled 1 package in [TIME]
      - flit-editable==0.1.0 (from file://[WORKSPACE]/test/packages/flit_editable)
-    "###
+    "
     );
 
     context.assert_command("import flit_editable").failure();
@@ -328,7 +313,7 @@ fn uninstall_duplicate() -> Result<()> {
 
     // Run `pip uninstall`.
     uv_snapshot!(context1.pip_uninstall()
-        .arg("pip"), @r###"
+        .arg("pip"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -337,7 +322,7 @@ fn uninstall_duplicate() -> Result<()> {
     Uninstalled 2 packages in [TIME]
      - pip==21.3.1
      - pip==22.1.1
-    "###
+    "
     );
 
     Ok(())
@@ -384,7 +369,7 @@ fn uninstall_egg_info() -> Result<()> {
 
     // Run `pip uninstall`.
     uv_snapshot!(context.pip_uninstall()
-        .arg("zstandard"), @r###"
+        .arg("zstandard"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -392,7 +377,7 @@ fn uninstall_egg_info() -> Result<()> {
     ----- stderr -----
     Uninstalled 1 package in [TIME]
      - zstandard==0.22.0
-    "###);
+    ");
 
     Ok(())
 }
@@ -438,7 +423,7 @@ Version: 0.22.0
 
     // Run `pip uninstall`.
     uv_snapshot!(context.pip_uninstall()
-        .arg("zstandard"), @r###"
+        .arg("zstandard"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -446,7 +431,7 @@ Version: 0.22.0
     ----- stderr -----
     Uninstalled 1 package in [TIME]
      - zstandard==0.22.0
-    "###);
+    ");
 
     // The entry in `easy-install.pth` should be removed.
     assert_eq!(
@@ -503,7 +488,7 @@ fn dry_run_uninstall_egg_info() -> Result<()> {
     // Run `pip uninstall`.
     uv_snapshot!(context.pip_uninstall()
         .arg("--dry-run")
-        .arg("zstandard"), @r###"
+        .arg("zstandard"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -511,7 +496,7 @@ fn dry_run_uninstall_egg_info() -> Result<()> {
     ----- stderr -----
     Would uninstall 1 package
      - zstandard==0.22.0
-    "###);
+    ");
 
     // The `.egg-info` directory should still exist.
     assert!(
