@@ -23,7 +23,7 @@ fn tool_list() {
 
     uv_snapshot!(context.filters(), context.tool_list()
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -32,7 +32,7 @@ fn tool_list() {
     - blackd
 
     ----- stderr -----
-    "###);
+    ");
 }
 
 #[test]
@@ -52,7 +52,7 @@ fn tool_list_paths() {
 
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-paths")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -61,7 +61,7 @@ fn tool_list_paths() {
     - blackd ([TEMP_DIR]/bin/blackd)
 
     ----- stderr -----
-    "###);
+    ");
 }
 
 #[cfg(windows)]
@@ -104,14 +104,14 @@ fn tool_list_empty() {
 
     uv_snapshot!(context.filters(), context.tool_list()
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
     No tools installed
-    "###);
+    ");
 }
 
 #[test]
@@ -133,14 +133,14 @@ fn tool_list_missing_receipt() {
 
     uv_snapshot!(context.filters(), context.tool_list()
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
     warning: Ignoring malformed tool `black` (run `uv tool uninstall black` to remove)
-    "###);
+    ");
 }
 
 #[test]
@@ -180,7 +180,7 @@ fn tool_list_bad_environment() -> Result<()> {
             .tool_list()
             .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
             .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()),
-        @r"
+        @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -214,7 +214,7 @@ fn tool_list_deprecated() -> Result<()> {
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(fs_err::read_to_string(tool_dir.join("black").join("uv-receipt.toml")).unwrap(), @r###"
+        assert_snapshot!(fs_err::read_to_string(tool_dir.join("black").join("uv-receipt.toml")).unwrap(), @r#"
         [tool]
         requirements = [{ name = "black", specifier = "==24.2.0" }]
         entrypoints = [
@@ -224,7 +224,7 @@ fn tool_list_deprecated() -> Result<()> {
 
         [tool.options]
         exclude-newer = "2024-03-25T00:00:00Z"
-        "###);
+        "#);
     });
 
     // Replace with a legacy receipt.
@@ -243,7 +243,7 @@ fn tool_list_deprecated() -> Result<()> {
     // Ensure that we can still list the tool.
     uv_snapshot!(context.filters(), context.tool_list()
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -252,7 +252,7 @@ fn tool_list_deprecated() -> Result<()> {
     - blackd
 
     ----- stderr -----
-    "###);
+    ");
 
     // Replace with an invalid receipt.
     fs::write(
@@ -270,14 +270,14 @@ fn tool_list_deprecated() -> Result<()> {
     // Ensure that listing fails.
     uv_snapshot!(context.filters(), context.tool_list()
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
     warning: Ignoring malformed tool `black` (run `uv tool uninstall black` to remove)
-    "###);
+    ");
 
     Ok(())
 }
@@ -308,7 +308,7 @@ fn tool_list_show_version_specifiers() {
 
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-version-specifiers")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -319,12 +319,12 @@ fn tool_list_show_version_specifiers() {
     - flask
 
     ----- stderr -----
-    "###);
+    ");
 
     // with paths
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-version-specifiers").arg("--show-paths")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -335,7 +335,7 @@ fn tool_list_show_version_specifiers() {
     - flask ([TEMP_DIR]/bin/flask)
 
     ----- stderr -----
-    "###);
+    ");
 }
 
 #[test]
@@ -380,7 +380,7 @@ fn tool_list_show_with() {
     // Test with --show-with
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-with")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -393,12 +393,12 @@ fn tool_list_show_with() {
     - ruff
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with both --show-with and --show-paths
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-with").arg("--show-paths")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -411,12 +411,12 @@ fn tool_list_show_with() {
     - ruff ([TEMP_DIR]/bin/ruff)
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with both --show-with and --show-version-specifiers
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-with").arg("--show-version-specifiers")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -429,7 +429,7 @@ fn tool_list_show_with() {
     - ruff
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with all flags
     uv_snapshot!(context.filters(), context.tool_list()
@@ -437,7 +437,7 @@ fn tool_list_show_with() {
     .arg("--show-version-specifiers")
     .arg("--show-paths")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -450,7 +450,7 @@ fn tool_list_show_with() {
     - ruff ([TEMP_DIR]/bin/ruff)
 
     ----- stderr -----
-    "###);
+    ");
 }
 
 #[test]
@@ -482,7 +482,7 @@ fn tool_list_show_extras() {
     // Test with --show-extras only
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-extras")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -493,12 +493,12 @@ fn tool_list_show_extras() {
     - flask
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with both --show-extras and --show-with
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-extras").arg("--show-with")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -509,12 +509,12 @@ fn tool_list_show_extras() {
     - flask
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with --show-extras and --show-paths
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-extras").arg("--show-paths")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -525,12 +525,12 @@ fn tool_list_show_extras() {
     - flask ([TEMP_DIR]/bin/flask)
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with --show-extras and --show-version-specifiers
     uv_snapshot!(context.filters(), context.tool_list().arg("--show-extras").arg("--show-version-specifiers")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -541,7 +541,7 @@ fn tool_list_show_extras() {
     - flask
 
     ----- stderr -----
-    "###);
+    ");
 
     // Test with all flags including --show-extras
     uv_snapshot!(context.filters(), context.tool_list()
@@ -550,7 +550,7 @@ fn tool_list_show_extras() {
     .arg("--show-version-specifiers")
     .arg("--show-paths")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -561,5 +561,83 @@ fn tool_list_show_extras() {
     - flask ([TEMP_DIR]/bin/flask)
 
     ----- stderr -----
-    "###);
+    ");
+}
+
+#[test]
+fn tool_list_show_python() {
+    let context = TestContext::new("3.12").with_filtered_exe_suffix();
+    let tool_dir = context.temp_dir.child("tools");
+    let bin_dir = context.temp_dir.child("bin");
+
+    // Install `black` with python 3.12
+    context
+        .tool_install()
+        .arg("black==24.2.0")
+        .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+        .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str())
+        .assert()
+        .success();
+
+    // Test with --show-python
+    uv_snapshot!(context.filters(), context.tool_list().arg("--show-python")
+    .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    black v24.2.0 [CPython 3.12.[X]]
+    - black
+    - blackd
+
+    ----- stderr -----
+    ");
+}
+
+#[test]
+fn tool_list_show_all() {
+    let context = TestContext::new("3.12").with_filtered_exe_suffix();
+    let tool_dir = context.temp_dir.child("tools");
+    let bin_dir = context.temp_dir.child("bin");
+
+    // Install `black` without extras
+    context
+        .tool_install()
+        .arg("black==24.2.0")
+        .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+        .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str())
+        .assert()
+        .success();
+
+    // Install `flask` with extras and additional requirements
+    context
+        .tool_install()
+        .arg("flask[async,dotenv]")
+        .arg("--with")
+        .arg("requests")
+        .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+        .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str())
+        .assert()
+        .success();
+
+    // Test with all flags
+    uv_snapshot!(context.filters(), context.tool_list()
+    .arg("--show-extras")
+    .arg("--show-with")
+    .arg("--show-version-specifiers")
+    .arg("--show-paths")
+    .arg("--show-python")
+    .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    black v24.2.0 [required: ==24.2.0] [CPython 3.12.[X]] ([TEMP_DIR]/tools/black)
+    - black ([TEMP_DIR]/bin/black)
+    - blackd ([TEMP_DIR]/bin/blackd)
+    flask v3.0.2 [extras: async, dotenv] [with: requests] [CPython 3.12.[X]] ([TEMP_DIR]/tools/flask)
+    - flask ([TEMP_DIR]/bin/flask)
+
+    ----- stderr -----
+    ");
 }
